use crate::{config::Config, schema, token, UIDCError};
use microrm::prelude::*;

pub fn create_auth_token(
    qi: &microrm::QueryInterface,
    config: &Config,
    realm_id: schema::RealmID,
    client: &str,
    username: &str,
    scopes: &str,
) -> Result<String, UIDCError> {
    Ok(token::generate_auth_token(
        config,
        qi,
        realm_id,
        qi.get().only_ids()
            .by(schema::Client::Realm, &realm_id)
            .by(schema::Client::Shortname, client)
            .one_id()?
            .ok_or(UIDCError::Abort("no such client"))?,
        qi.get().only_ids()
            .by(schema::User::Realm, &realm_id)
            .by(schema::User::Username, username)
            .one_id()?
            .ok_or(UIDCError::Abort("no such user"))?,
        scopes.split_whitespace(),
    )?)
}
